.. _testing-contracts:

Testing a Contract
##################

For testing Vyper contracts we recommend the use of `pytest <https://docs.pytest.org/en/latest/contents.html>`_ along with one of the following packages:

    * `Brownie <https://github.com/iamdefinitelyahuman/brownie>`_: A development and testing framework for smart contracts targeting the Ethereum Virtual Machine
    * `Ethereum Tester <https://github.com/ethereum/eth-tester>`_: A tool suite for testing ethereum applications

Example usage for each package is provided in the sections listed below.

.. toctree::
    :maxdepth: 2

    testing-contracts-brownie.rst
    testing-contracts-ethtester.rst
